@@ -1,7 +1,8 @@
 package Time::Duration::Parse;
 
 use strict;
-our $VERSION = '0.06';
+use warnings;
+our $VERSION = '0.07';
 
 use Carp;
 use Exporter::Lite;
@@ -88,6 +89,8 @@ Parses duration string and returns seconds. When it encounters an
 error in a given string, it dies an exception saying "Unknown
 timespec: blah blah blah". This function is exported by default.
 
+=back
+
 =head1 AUTHOR
 
 Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>
